==> elgg-1.8.19.zip: elgg-1.8.19/mod/blog/languages/en.php <==
<?php
/**
 * Blog English language file.
 *
 */

$english = array(
	'blog' => 'Blogs',
	'blog:blogs' => 'Blogs',
	'blog:revisions' => 'Revisions',
	'blog:archives' => 'Archives',
	'blog:blog' => 'Blog',
	'item:object:blog' => 'Blogs',

	'blog:title:user_blogs' => '%s\'s blogs',
	'blog:title:all_blogs' => 'All site blogs',
	'blog:title:friends' => 'Friends\' blogs',

	'blog:group' => 'Group blog',
	'blog:enableblog' => 'Enable group blog',
	'blog:write' => 'Write a blog post',

	// Editing
	'blog:add' => 'Add blog post',
	'blog:edit' => 'Edit blog post',
	'blog:excerpt' => 'Excerpt',
	'blog:body' => 'Body',
	'blog:save_status' => 'Last saved: ',
	'blog:never' => 'Never',

	// Statuses
	'blog:status' => 'Status',
	'blog:status:draft' => 'Draft',
	'blog:status:published' => 'Published',
	'blog:status:unsaved_draft' => 'Unsaved Draft',

	'blog:revision' => 'Revision',
	'blog:auto_saved_revision' => 'Auto Saved Revision',

	// messages
	'blog:message:saved' => 'Blog post saved.',
	'blog:error:cannot_save' => 'Cannot save blog post.',
	'blog:error:cannot_write_to_container' => 'Insufficient access to save blog to group.',
	'blog:messages:warning:draft' => 'There is an unsaved draft of this post!',
	'blog:edit_revision_notice' => '(Old version)',
	'blog:message:deleted_post' => 'Blog post deleted.',
	'blog:error:cannot_delete_post' => 'Cannot delete blog post.',
	'blog:none' => 'No blog posts',
	'blog:error:missing:title' => 'Please enter a blog title!',
	'blog:error:missing:description' => 'Please enter the body of your blog!',
	'blog:error:cannot_edit_post' => 'This post may not exist or you may not have permissions to edit it.',
	'blog:error:revision_not_found' => 'Cannot find this revision.',

	// river
	'river:create:object:blog' => '%s published a blog post %s',
	'river:comment:object:blog' => '%s commented on the blog %s',

	// notifications
	'blog:newpost' => 'A new blog post',
	'blog:notification' =>
'
%s made a new blog post.

%s
%s

View and comment on the new blog post:
%s
',

	// widget
	'blog:widget:description' => 'Display your latest blog posts',
	'blog:moreblogs' => 'More blog posts',
	'blog:numbertodisplay' => 'Number of blog posts to display',
	'blog:noblogs' => 'No blog posts'
);

add_translation('en', $english);

==> elgg-1.11.0.zip: elgg-1.11.0/mod/blog/languages/en.php <==
<?php
return array(
	'blog' => 'Blogs',
	'blog:blogs' => 'Blogs',
	'blog:revisions' => 'Revisions',
	'blog:archives' => 'Archives',
	'blog:blog' => 'Blog',
	'item:object:blog' => 'Blogs',

	'blog:title:user_blogs' => '%s\'s blogs',
	'blog:title:all_blogs' => 'All site blogs',
	'blog:title:friends' => 'Friends\' blogs',

	'blog:group' => 'Group blog',
	'blog:enableblog' => 'Enable group blog',
	'blog:write' => 'Write a blog post',

	// Editing
	'blog:add' => 'Add blog post',
	'blog:edit' => 'Edit blog post',
	'blog:excerpt' => 'Excerpt',
	'blog:body' => 'Body',
	'blog:save_status' => 'Last saved: ',
	
	'blog:revision' => 'Revision',
	'blog:auto_saved_revision' => 'Auto Saved Revision',

	// messages
	'blog:message:saved' => 'Blog post saved.',
	'blog:error:cannot_save' => 'Cannot save blog post.',
	'blog:error:cannot_auto_save' => 'Cannot automatically save blog post.',
	'blog:error:cannot_write_to_container' => 'Insufficient access to save blog to group.',
	'blog:messages:warning:draft' => 'There is an unsaved draft of this post!',
	'blog:edit_revision_notice' => '(Old version)',
	'blog:message:deleted_post' => 'Blog post deleted.',
	'blog:error:cannot_delete_post' => 'Cannot delete blog post.',
	'blog:none' => 'No blog posts',
	'blog:error:missing:title' => 'Please enter a blog title!',
	'blog:error:missing:description' => 'Please enter the body of your blog!',
	'blog:error:cannot_edit_post' => 'This post may not exist or you may not have permissions to edit it.',
	'blog:error:post_not_found' => 'Cannot find specified blog post.',
	'blog:error:revision_not_found' => 'Cannot find this revision.',

	// river
	'river:create:object:blog' => '%s published a blog post %s',
	'river:comment:object:blog' => '%s commented on the blog %s',

	// notifications
	'blog:notify:summary' => 'New blog post called %s',
	'blog:notify:subject' => 'New blog post: %s',
	'blog:notify:body' =>
'
%s published a new blog post: %s

%s

View and comment on the blog post:
%s
',

	// widget
	'blog:widget:description' => 'Display your latest blog posts',
	'blog:moreblogs' => 'More blog posts',
	'blog:numbertodisplay' => 'Number of blog posts to display',
	'blog:noblogs' => 'No blog posts'
);
